#!/usr/bin/env python3
# Copyright (C) 2025 Spearhead Systems SRL

import datetime
import json
from cmk.agent_based.v2 import Result, Service, State, CheckPlugin, AgentSection


# Incoming agent output is JSON of the form:
#
# {"domain": "google.com", "state": "CRIT", "expires": "2028-09-14"}
#
# "domain" and "state" are always present, whereas "expires" is optional
# (e.g. most ccTLDs do not return expiry information). The "state" is one of
# (OK, WARN, CRIT, UNKNOWN).
#
# Return a dictionary which uses domain as key, and the rest of the dictionary
# as a value.
def parse_domains_expiry(string_table):
    results = {}

    for [line] in string_table:
        result = json.loads(line)
        results[result["domain"]] = result

    return results


def discover_domains_expiry(section):
    for domain in section.keys():
        yield Service(item=domain)


def check_domains_expiry(item, params, section):
    data = section.get(item)
    if not data:
        yield Result(state=State.WARN, summary="Expiry not found in whois")
        return

    state = State[data["state"]]
    expiry = data.get("expires")

    if expiry:
        summary = f"Expires on {expiry}"
    else:
        summary = "No expiry found"

    yield Result(state=state, summary=summary)


agent_section_domains_expiry = AgentSection(
    name="domains_expiry",
    parse_function=parse_domains_expiry
)

check_plugin_domains_expiry = CheckPlugin(
    name="domains_expiry",
    service_name="Expiry for Domain '%s'",

    discovery_function=discover_domains_expiry,

    check_function=check_domains_expiry,
    check_default_parameters={},
)
